@@ -142,7 +142,7 @@ pub fn call_dylib_edn_fn(xs: &CalcitItems, call_stack: &CallStackList) -> Result
           for p in ps {
             real_args = real_args.push(edn_to_calcit(&p));
           }
-          let r = runner::run_fn(&real_args, scope, args, body, def_ns.to_owned(), &copied_stack);
+          let r = runner::run_fn(&real_args, scope, args.to_owned(), body, def_ns.to_owned(), &copied_stack);
           match r {
             Ok(ret) => calcit_to_edn(&ret),
             Err(e) => {
@@ -160,7 +160,8 @@ pub fn call_dylib_edn_fn(xs: &CalcitItems, call_stack: &CallStackList) -> Result
       Ok(ret) => edn_to_calcit(&ret),
       Err(e) => {
         track::track_task_release();
-        let _ = display_stack(&format!("failed to call request: {}", e), &copied_stack_1);
+        // let _ = display_stack(&format!("failed to call request: {}", e), &copied_stack_1);
+        println!("failure inside ffi thread: {}", e);
         return CalcitErr::err_str(e);
       }
     };
@@ -229,7 +230,7 @@ pub fn blocking_dylib_edn_fn(xs: &CalcitItems, call_stack: &CallStackList) -> Re
         for p in ps {
           real_args = real_args.push(edn_to_calcit(&p));
         }
-        let r = runner::run_fn(&real_args, scope, args, body, def_ns.to_owned(), &copied_stack.clone());
+        let r = runner::run_fn(&real_args, scope, args.to_owned(), body, def_ns.to_owned(), &copied_stack.clone());
         match r {
           Ok(ret) => calcit_to_edn(&ret),
           Err(e) => {
@@ -246,7 +247,8 @@ pub fn blocking_dylib_edn_fn(xs: &CalcitItems, call_stack: &CallStackList) -> Re
   ) {
     Ok(ret) => edn_to_calcit(&ret),
     Err(e) => {
-      track::track_task_release();
+      // TODO for more accurate tracking, need to place tracker inside foreign function
+      // track::track_task_release();
       let _ = display_stack(&format!("failed to call request: {}", e), call_stack);
       return CalcitErr::err_str(e);
     }
@@ -266,7 +268,14 @@ pub fn on_ctrl_c(xs: &CalcitItems, call_stack: &CallStackList) -> Result<Calcit,
         def_ns, scope, args, body, ..
       } = cb.as_ref()
       {
-        if let Err(e) = runner::run_fn(&TernaryTreeList::Empty, scope, args, body, def_ns.to_owned(), &copied_stack) {
+        if let Err(e) = runner::run_fn(
+          &TernaryTreeList::Empty,
+          scope,
+          args.to_owned(),
+          body,
+          def_ns.to_owned(),
+          &copied_stack,
+        ) {
           println!("error: {}", e);
         }
       }
