@@ -194,7 +194,7 @@ pub fn foldl(xs: &CalcitItems, call_stack: &CallStackList) -> Result<Calcit, Cal
       ) => {
         for x in xs {
           let values = TernaryTreeList::from(&[ret, x.to_owned()]);
-          ret = runner::run_fn(&values, scope, args, body, def_ns.to_owned(), call_stack)?;
+          ret = runner::run_fn(&values, scope, args.to_owned(), body, def_ns.to_owned(), call_stack)?;
         }
         Ok(ret)
       }
@@ -214,7 +214,7 @@ pub fn foldl(xs: &CalcitItems, call_stack: &CallStackList) -> Result<Calcit, Cal
       ) => {
         for x in xs {
           let values = TernaryTreeList::from(&[ret, x.to_owned()]);
-          ret = runner::run_fn(&values, scope, args, body, def_ns.to_owned(), call_stack)?;
+          ret = runner::run_fn(&values, scope, args.to_owned(), body, def_ns.to_owned(), call_stack)?;
         }
         Ok(ret)
       }
@@ -234,7 +234,7 @@ pub fn foldl(xs: &CalcitItems, call_stack: &CallStackList) -> Result<Calcit, Cal
       ) => {
         for (k, x) in xs {
           let values = TernaryTreeList::from(&[ret, Calcit::List(TernaryTreeList::from(&[k.to_owned(), x.to_owned()]))]);
-          ret = runner::run_fn(&values, scope, args, body, def_ns.to_owned(), call_stack)?;
+          ret = runner::run_fn(&values, scope, args.to_owned(), body, def_ns.to_owned(), call_stack)?;
         }
         Ok(ret)
       }
@@ -280,7 +280,7 @@ pub fn foldl_shortcut(xs: &CalcitItems, call_stack: &CallStackList) -> Result<Ca
         let mut state = acc.to_owned();
         for x in xs {
           let values = TernaryTreeList::from(&[state, x.to_owned()]);
-          let pair = runner::run_fn(&values, scope, args, body, def_ns.to_owned(), call_stack)?;
+          let pair = runner::run_fn(&values, scope, args.to_owned(), body, def_ns.to_owned(), call_stack)?;
           match pair {
             Calcit::Tuple(x0, x1) => match &*x0 {
               Calcit::Bool(b) => {
@@ -317,7 +317,7 @@ pub fn foldl_shortcut(xs: &CalcitItems, call_stack: &CallStackList) -> Result<Ca
         let mut state = acc.to_owned();
         for x in xs {
           let values = TernaryTreeList::from(&[state, x.to_owned()]);
-          let pair = runner::run_fn(&values, scope, args, body, def_ns.to_owned(), call_stack)?;
+          let pair = runner::run_fn(&values, scope, args.to_owned(), body, def_ns.to_owned(), call_stack)?;
           match pair {
             Calcit::Tuple(x0, x1) => match &*x0 {
               Calcit::Bool(b) => {
@@ -354,7 +354,7 @@ pub fn foldl_shortcut(xs: &CalcitItems, call_stack: &CallStackList) -> Result<Ca
         let mut state = acc.to_owned();
         for (k, x) in xs {
           let values = TernaryTreeList::from(&[state, Calcit::List(TernaryTreeList::from(&[k.to_owned(), x.to_owned()]))]);
-          let pair = runner::run_fn(&values, scope, args, body, def_ns.to_owned(), call_stack)?;
+          let pair = runner::run_fn(&values, scope, args.to_owned(), body, def_ns.to_owned(), call_stack)?;
           match pair {
             Calcit::Tuple(x0, x1) => match &*x0 {
               Calcit::Bool(b) => {
@@ -414,7 +414,7 @@ pub fn foldr_shortcut(xs: &CalcitItems, call_stack: &CallStackList) -> Result<Ca
         for i in 0..size {
           let x = xs[size - 1 - i].to_owned();
           let values = TernaryTreeList::from(&[state, x]);
-          let pair = runner::run_fn(&values, scope, args, body, def_ns.to_owned(), call_stack)?;
+          let pair = runner::run_fn(&values, scope, args.to_owned(), body, def_ns.to_owned(), call_stack)?;
           match pair {
             Calcit::Tuple(x0, x1) => match &*x0 {
               Calcit::Bool(b) => {
@@ -468,7 +468,7 @@ pub fn sort(xs: &CalcitItems, call_stack: &CallStackList) -> Result<Calcit, Calc
         let mut xs2: Vec<&Calcit> = xs.into_iter().collect::<Vec<&Calcit>>();
         xs2.sort_by(|a, b| -> Ordering {
           let values = TernaryTreeList::from(&[a.to_owned().to_owned(), b.to_owned().to_owned()]);
-          let v = runner::run_fn(&values, scope, args, body, def_ns.to_owned(), call_stack);
+          let v = runner::run_fn(&values, scope, args.to_owned(), body, def_ns.to_owned(), call_stack);
           match v {
             Ok(Calcit::Number(x)) if x < 0.0 => Ordering::Less,
             Ok(Calcit::Number(x)) if x == 0.0 => Ordering::Equal,
