@@ -100,7 +100,7 @@ pub fn tmpl_tail_recursion(
 pub fn tmpl_import_procs(name: String) -> String {
   format!(
     "
-import {{kwd, arrayToList, listToArray, CalcitList, CalcitSymbol, CalcitRecur}} from {};
+import {{kwd, arrayToList, listToArray, CalcitSliceList, CalcitSymbol, CalcitRecur}} from {};
 import * as $calcit_procs from {};
 export * from {};
 ",
@@ -142,3 +142,14 @@ if (runtimeVersion !== cli_version) {{
     CALCIT_VERSION
   )
 }
+
+pub fn tmpl_keywords_init(arr: &str, prefix: &str) -> String {
+  format!(
+    "
+{}.forEach(x => {{
+  _kwd[x] = {}kwd(x);
+}});
+  ",
+    arr, prefix
+  )
+}
