@@ -4,7 +4,7 @@ use std::sync::Arc;
 
 use crate::data::cirru;
 use crate::primes;
-use crate::primes::{Calcit, CrListWrap};
+use crate::primes::Calcit;
 
 use cirru_edn::{Edn, EdnKwd};
 use im_ternary_tree::TernaryTreeList;
@@ -47,7 +47,7 @@ pub fn calcit_to_edn(x: &Calcit) -> Result<Edn, String> {
       Ok(Edn::Record(name.to_owned(), entries))
     }
     Calcit::Fn { name, def_ns, args, .. } => {
-      println!("[Warn] fn to EDN: {}/{} {}", def_ns, name, CrListWrap((**args).to_owned()));
+      println!("[Warn] fn to EDN: {}/{} {:?}", def_ns, name, args);
       Ok(Edn::str(x.to_string()))
     }
     Calcit::Proc(name) => Ok(Edn::Symbol((**name).into())),
